==> gtk-recordmydesktop_0.3.4.orig.tar.gz: gtk-recordmydesktop-0.3.4/src/rmdConfig.py <==
import os
VERSION='0.3.4'
PREFIX='/usr/'
locale_install_dir=os.path.join('${prefix}/share'.replace("${prefix}",PREFIX), 'locale')

#binary values expressed with 1 and zero instead of True and False
#are upside down. That means 0 is enabled and 1 disabled

default_values=[15,     #framerate
                0,      #cursor
                True,   #sound
                1,      #full shots,0 on 1 off
                os.path.join(os.getenv('HOME'),'out.ogg'), #filename
                [-1,-1,-1,-1],  #recording area(<0 means auto)
                0,          #delay ,unused on 0.3
                1,          #no of channels
                22050,      #frequency
                'DEFAULT',  #device
                63,         #video quality
                10,         #audio quality
                "$DISPLAY", #display, this is not interpreted as an env variable
                            #but when the value is set to this the argument is omitted
                0,          #shared memory,0 on 1 off
                1,          #drop frames,unused in 0.3,0, removed at 0.3.4, preserved for compatibility of prefs file.
                75,         #shared threshold.Removed at 0.3.4, preserved for compatibility of prefs file.
                1,          #quick subsampling,0 on 1 off
                "/tmp",     #working directory
                1,          #on the fly encoding,0 on 1 off
                1,          #zero compression,0 on 1 off
                False,      #overwrite existing files
                0,          #include window decorations, 0 on 1 off
                False,      #Use jack
                [],         #jack ports
                0,          #tooltips,0 on 1 off
                0,          #draw an on-screen frame, surrounding the capture area,0 on 1 off
                ]

==> gtk-recordmydesktop_0.3.6.orig.tar.gz: gtk-recordmydesktop-0.3.6/src/rmdConfig.py <==
import os
VERSION='0.3.6'
PREFIX='/usr/'
locale_install_dir=os.path.join('${prefix}/share'.replace("${prefix}",PREFIX), 'locale')

#binary values expressed with 1 and zero instead of True and False
#are upside down. That means 0 is enabled and 1 disabled

default_values=[15,     #framerate
                0,      #cursor
                True,   #sound
                1,      #full shots,0 on 1 off
                os.path.join(os.getenv('HOME'),'out.ogg'), #filename
                [-1,-1,-1,-1],  #recording area(<0 means auto)
                0,          #delay ,unused on 0.3
                1,          #no of channels
                22050,      #frequency
                'DEFAULT',  #device
                63,         #video quality
                10,         #audio quality
                "$DISPLAY", #display, this is not interpreted as an env variable
                            #but when the value is set to this the argument is omitted
                0,          #shared memory,0 on 1 off
                0,          #reset recording area ,0 on 1 off
                1,          #follow mouse,0 on 1 off
                1,          #quick subsampling,0 on 1 off
                "/tmp",     #working directory
                1,          #on the fly encoding,0 on 1 off
                0,          #zero compression,0 on 1 off
                False,      #overwrite existing files
                0,          #include window decorations, 0 on 1 off
                False,      #Use jack
                [],         #jack ports
                0,          #tooltips,0 on 1 off
                0,          #draw an on-screen frame, surrounding the capture area,0 on 1 off
                "",         #extra options
                ]
